{
  stdenv
, makeDesktopItem, writeScript, fetchurl
, chromium
}:

let
  script = writeScript "run-discord-app.sh" ''
  ${chromium}/bin/chromium \
    --class="Discord-App" \
    --app="https://discord.com/channels/@me" \
    --user-data-dir=$HOME/.local/share/discord-app
'';
  desktopItem = makeDesktopItem {
    name = "discord-app";
    desktopName = "Discord App";
    genericName = "All-in-one cross-platform voice and text chat for gamers";
    exec = "${script}";
    icon = "discord";
    type = "Application";
    categories = [ "Network" "InstantMessaging" ];
    startupWMClass = "Discord-App";
  };
  iconSvg = fetchurl {
    url = "https://discord.com/assets/3437c10597c1526c3dbd98c737c2bcae.svg";
    sha256 = "0w18j5pvqnaimnsx9flqm8n5yb7lnkc5jsvf1c9sk5a3jplq2j61";
  };
in stdenv.mkDerivation {
  pname = "discord-app";
  version = "1.0.0";

  buildInputs = [ chromium ];

  phases = "installPhase";
  
  installPhase = ''
    # Install the icon
    mkdir -p $out/share/pixmaps
    cp ${iconSvg} $out/share/pixmaps/discord.svg

    mkdir -p $out/bin
    cp ${script} $out/bin/discord-app
    cp -r ${desktopItem}/share/* $out/share
  '';
}

